"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.createNotification = createNotification;
exports.notificationSent = notificationSent;
exports.setNotificationPermission = setNotificationPermission;
exports.setNotificationSupported = setNotificationSupported;
exports.UPDATE_NOTIFICATION_SETTING = exports.DELETE_NOTIFICATION = exports.ADD_NOTIFICATION = void 0;
var ADD_NOTIFICATION = 'notifications/ADD_NOTIFICATION';
exports.ADD_NOTIFICATION = ADD_NOTIFICATION;
var DELETE_NOTIFICATION = 'notifications/DELETE_NOTIFICATION';
exports.DELETE_NOTIFICATION = DELETE_NOTIFICATION;
var UPDATE_NOTIFICATION_SETTING = 'notifications/UPDATE_NOTIFICATION_SETTING';
exports.UPDATE_NOTIFICATION_SETTING = UPDATE_NOTIFICATION_SETTING;

function addNotification(notification) {
  return {
    type: ADD_NOTIFICATION,
    payload: {
      notification: notification
    }
  };
}

function deleteNotification(notificationId) {
  return {
    type: DELETE_NOTIFICATION,
    payload: {
      notificationId: notificationId
    }
  };
}

function updateNotificationSetting(setting) {
  return {
    type: UPDATE_NOTIFICATION_SETTING,
    payload: {
      setting: setting
    }
  };
}
/**
 * Creates a new notification for processing
 *
 * @param {string} notificationId
 * @param {object} details
 * @param {string} details.message
 * @param {string} details.avatar
 * @param {string} details.username
 * @returns {function}
 */


function createNotification(notificationId, details) {
  return function (dispatch) {
    return dispatch(addNotification({
      notificationId: notificationId,
      details: details
    }));
  };
}
/**
 * Updates an existing notification to indicate that it was sent
 *
 * @param {string} notificationId
 * @returns {function}
 */


function notificationSent(notificationId) {
  return function (dispatch) {
    return dispatch(deleteNotification(notificationId));
  };
}
/**
 * Changes the permission type after we've request notification
 * permissions from the user
 *
 * @param {String} permission
 * @returns {function}
 */


function setNotificationPermission(permission) {
  return function (dispatch) {
    return dispatch(updateNotificationSetting({
      permission: permission
    }));
  };
}
/**
 * Changes the setting for if native notifications are supported
 * by the user's device/browser
 *
 * @export
 * @param {bool} isSupported
 * @returns {function}
 */


function setNotificationSupported(isSupported) {
  return function (dispatch) {
    return dispatch(updateNotificationSetting({
      isSupported: isSupported
    }));
  };
}