"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.isBrowserHidden = isBrowserHidden;
exports.isNotificationSupported = isNotificationSupported;
exports.requestPermissionForNotifications = requestPermissionForNotifications;
exports.spawnNotification = spawnNotification;
exports.default = exports.PERMISSION_DENIED = exports.PERMISSION_GRANTED = void 0;
var PERMISSION_GRANTED = 'granted';
exports.PERMISSION_GRANTED = PERMISSION_GRANTED;
var PERMISSION_DENIED = 'denied';
/**
 * Returns true if the main browser window is hidden, minimized,
 * or in the background; false otherwise.
 *
 * @returns {boolean} hidden
 */

exports.PERMISSION_DENIED = PERMISSION_DENIED;

function isBrowserHidden() {
  return document.webkitHidden || document.mozHidden || document.msHidden || document.hidden || !document.hasFocus();
}
/**
 * Checks if native browser notifications are supported
 *
 * @export
 * @returns {bool}
 */


function isNotificationSupported() {
  return window && window.Notification;
}

function requestPermissionForNotifications(callback) {
  return window.Notification.requestPermission(callback);
}
/**
 * Displays a browser notification and automatically closes after timeout
 *
 * @param {String} theBody body of the notification
 * @param {String} theIcon the url of the icon to display
 * @param {String} theTitle
 * @param {Integer} timeoutLength non-zero amount of time to display the notification
 *
 * @returns {Object} Browser notification object
 *
 */


function spawnNotification(theBody, theIcon, theTitle, timeoutLength) {
  var options = {
    body: theBody,
    icon: theIcon
  };
  var browserNotification = new Notification(theTitle, options);

  if (timeoutLength) {
    setTimeout(function () {
      browserNotification.close();
    }, timeoutLength);
  }

  return browserNotification;
}

var _default = {
  PERMISSION_GRANTED: PERMISSION_GRANTED,
  PERMISSION_DENIED: PERMISSION_DENIED,
  isBrowserHidden: isBrowserHidden,
  isNotificationSupported: isNotificationSupported,
  requestPermissionForNotifications: requestPermissionForNotifications,
  spawnNotification: spawnNotification
};
exports.default = _default;