"use strict";

var _interopRequireWildcard = require("@babel/runtime-corejs2/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.default = exports.Notifications = void 0;

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/createClass"));

var _possibleConstructorReturn2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/possibleConstructorReturn"));

var _getPrototypeOf2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/getPrototypeOf"));

var _inherits2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/inherits"));

var _react = _interopRequireWildcard(require("react"));

var _reactTransformHmr3 = _interopRequireDefault(require("react-transform-hmr"));

var _isNull2 = _interopRequireDefault(require("lodash/isNull"));

var _reactRedux = require("react-redux");

var _redux = require("redux");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _browserUtils = _interopRequireDefault(require("./browserUtils"));

var _selectors = _interopRequireDefault(require("./selectors"));

var _actions = require("./actions");

var _events = require("./events");

var _components = {
  Notifications: {
    displayName: "Notifications"
  }
};

var _reactTransformHmr2 = (0, _reactTransformHmr3.default)({
  filename: "packages/node_modules/@ciscospark/react-container-notifications/src/container.js",
  components: _components,
  locals: [module],
  imports: [_react.default]
});

function _wrapComponent(id) {
  return function (Component) {
    return _reactTransformHmr2(Component, id);
  };
}

var TIMEOUT_LENGTH = 10000;
var propTypes = {
  notifications: _propTypes.default.array,
  isSupported: _propTypes.default.bool,
  isMuted: _propTypes.default.bool,
  permission: _propTypes.default.string,
  onEvent: _propTypes.default.func,
  notificationSent: _propTypes.default.func,
  setNotificationPermission: _propTypes.default.func,
  setNotificationSupported: _propTypes.default.func
};
var defaultProps = {
  notifications: [],
  isSupported: false,
  isMuted: false,
  permission: '',
  onEvent: null,
  notificationSent: null,
  setNotificationPermission: null,
  setNotificationSupported: null
};

var Notifications =
/*#__PURE__*/
function (_Component) {
  (0, _inherits2.default)(Notifications, _Component);

  function Notifications() {
    (0, _classCallCheck2.default)(this, Notifications);
    return (0, _possibleConstructorReturn2.default)(this, (0, _getPrototypeOf2.default)(Notifications).apply(this, arguments));
  }

  (0, _createClass2.default)(Notifications, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var props = this.props; // Default state is not supported, once we know it is, don't check any more

      this.setup(props);
      this.displayNotifications();
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps) {
      var props = this.props;
      return nextProps.notifications !== props.notifications || nextProps.isSupported !== props.isSupported || nextProps.permission !== props.permission;
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this.setup(this.props);
      this.displayNotifications();
    }
    /**
     * Check for permissions and support
     *
     * @param {object} props
     * @returns null
     */

  }, {
    key: "setup",
    value: function setup(props) {
      if (!props.isSupported) {
        this.checkSupported();
      }

      if ((0, _isNull2.default)(props.permission) && props.isSupported) {
        this.requestPermission();
      }
    }
    /**
     * Requests permission from the browser to allow notifications
     *
     * @returns {Promise}
     */

  }, {
    key: "requestPermission",
    value: function requestPermission() {
      var props = this.props;
      return _browserUtils.default.requestPermissionForNotifications(function (permission) {
        return props.setNotificationPermission(permission);
      });
    }
    /**
     * Checks if browser notifications are supported and updates store
     *
     */

  }, {
    key: "checkSupported",
    value: function checkSupported() {
      var props = this.props;

      if (!props.isSupported && _browserUtils.default.isNotificationSupported()) {
        props.setNotificationSupported(true);
      }
    }
    /**
     * Processes notifications and displays them if needed
     *
     */

  }, {
    key: "displayNotifications",
    value: function displayNotifications() {
      var _this = this;

      var _this$props = this.props,
          notifications = _this$props.notifications,
          onEvent = _this$props.onEvent,
          permission = _this$props.permission,
          isMuted = _this$props.isMuted;
      var hasPermission = permission === _browserUtils.default.PERMISSION_GRANTED;

      if (notifications && notifications.length > 0) {
        notifications.forEach(function (notification) {
          var username = notification.username,
              message = notification.message,
              avatar = notification.avatar,
              notificationId = notification.notificationId,
              alertType = notification.alertType;

          if (alertType !== 'none' && !isMuted && hasPermission && _browserUtils.default.isBrowserHidden()) {
            // Actually display notification
            var n = _browserUtils.default.spawnNotification(message, avatar, username, TIMEOUT_LENGTH); // If there is an onEvent method


            var details = (0, _events.constructNotificationEventData)(n, notification);

            if (onEvent && typeof onEvent === 'function') {
              onEvent(_events.eventNames.NOTIFICATIONS_CREATED, details);
              n.addEventListener('click', function () {
                onEvent(_events.eventNames.NOTIFICATIONS_CLICKED, details);
              });
            }
          }

          _this.props.notificationSent(notificationId);
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      return null;
    }
  }]);
  return Notifications;
}(_react.Component);

exports.Notifications = Notifications;
exports.Notifications = Notifications = _wrapComponent("Notifications")(Notifications);
Notifications.propTypes = propTypes;
Notifications.defaultProps = defaultProps;

var _default2 = (0, _reactRedux.connect)(_selectors.default, function (dispatch) {
  return (0, _redux.bindActionCreators)({
    notificationSent: _actions.notificationSent,
    setNotificationPermission: _actions.setNotificationPermission,
    setNotificationSupported: _actions.setNotificationSupported
  }, dispatch);
})(Notifications);

exports.default = _default2;